#!/bin/ksh
# @(#)  Version 1.1  db_back.sh   Example  03/28/94
#=================================================================#
#   Script :  db_back.sh                                          #
#   Authors:  M. Crisanto / L. Denefleh  / F. Kraemer             #
#   Date   :  94/03/28                                            #
#   Update :  96/11/14                                            #
#   Info   :  This script saves the relevant NCS and              #
#             License Use Management                              #
#                     definition and database files.              #
#                                                                 #
#   Input  :  NONE                                                #
#                                                                 #
#   Output :  file /tmp/iforls_bak_$TODAY_$SERVER as backup       #
#             format file                                         #
#-----------------------------------------------------------------#
#set -x
export PATH=/bin:/usr/bin:/sbin:$PATH
BACKUP="tar"              #  pathname to backup command
PROG="$(basename $0)"                  #
#-----------------------------------------------------------------#
#  This is the usage information.                                 #
#-----------------------------------------------------------------#
usage()
{
 echo "\nUsage:  $PROG"
 echo "\n\tDefault backup of NCS and License Use Management related definitions"
 echo "\tand database files\n"
 exit 1
}
#-----------------------------------------------------------------#
#  Test for valid input or display usage() information.           #
#-----------------------------------------------------------------#
if [ "${1}" = '-h' -o "${1}" = '?' ]; then
   usage
fi
#-----------------------------------------------------------------#
#  Prepare the variables.                                         #
#-----------------------------------------------------------------#
integer RET
SERVER="$(hostname)"
TODAY=$(date +%m_%d_%y)
INF="/tmp/.ibackup.$$"                      #  temp. input file for backup
OUTF="/tmp/iforls_bak_${TODAY}_${SERVER}.tar" #  database backup file
#-----------------------------------------------------------------#
#                                                                 #
#  This is the shell script's master loop. It saves all           #
#  NCS and License Use Management definition and database files                  #
#  using the backup command.                                      #
#                                                                 #
#  ===> NOTE:                                                     #
#  The default configuration names are shown: please change them  #
#  according to your environment.                                 #
#  logdbNN, llmlgNN and crlogNN files can be also customized in   #
#  number: insert additional lines as needed.                     #
#-----------------------------------------------------------------#
rm $INF 1>/dev/null 2>/dev/null
#-----------------------------------------------------------------#
RET=$(${BACKUP} -cvf "${OUTF}" /var/lum/i4ls.ini 1>/dev/null 2>/dev/null)

 for FILENAME in /etc/lum/ncs/glb_site.txt  \
                 /etc/lum/ncs/glb_obj.txt   \
                 /etc/lum/ncs/glb.e         \
                 /etc/lum/ncs/glb.p         \
                 /etc/lum/ncs/glb_log       \
                 /var/lum/licdb.dat    \
                 /var/lum/licdb.idx    \
                 /var/lum/crpdb.dat    \
                 /var/lum/crpdb.idx    \
                 /var/lum/llmdb.dat    \
                 /var/lum/llmdb.idx    \
                 /var/lum/usrdb.dat    \
                 /var/lum/usrdb.idx    \
                 /var/lum/adddb.dat    \
                 /var/lum/adddb.idx    \
                 /var/lum/nodelock     \
                 /var/lum/i4ls.ini     \
                 /var/lum/user_file    \
                 /var/lum/logdb00_.dat \
                 /var/lum/logdb01.dat  \
                 /var/lum/logdb00_.idx \
                 /var/lum/logdb01.idx  \
                 /var/lum/crlog00_.dat \
                 /var/lum/crlog01.dat  \
                 /var/lum/crlog00_.idx \
                 /var/lum/crlog01.idx  \
                 /var/lum/llmlg00_.dat \
                 /var/lum/llmlg01.dat  \
                 /var/lum/llmlg00_.idx \
                 /var/lum/llmlg01.idx

  do
   if [ -f "$FILENAME" ]
   then
    echo "$FILENAME" >> $INF
    RET=$(${BACKUP} -uvf "${OUTF}" "${FILENAME}" 1>/dev/null 2>/dev/null)
   fi
  done
#-----------------------------------------------------------------#
#-----------------------------------------------------------------#
rm $INF 1>/dev/null 2>/dev/null
#-----------------------------------------------------------------#
# EOF                                                             #
#-----------------------------------------------------------------#
exit ${RET}

