#!/bin/ksh
# @(#)  Version 1.1  db_recov.sh   Example  03/30/94
#=================================================================#
#   Script :  db_recov.sh                                         #
#   Authors:  M. Crisanto / L. Denefleh  / F. Kraemer             #
#   Date   :  94/03/28                                            #
#   Update :  96/11/14                                            #
#   Info   :  This script recovers the NCS and License Use        #
#             Management definition                               #
#             database files from back-up media                   #
#                                                                 #
#   Input  :  filename of the backup format file                  #
#                                                                 #
#   Output :  information about performed steps                   #
#                                                                 #
#-----------------------------------------------------------------#
export PATH=/bin:/usr/bin:/sbin:$PATH
RESTORE="tar -xvf"            #  pathname to restore command
LSSRC="/usr/bin/lssrc"                 #  pathname to lssrc   command
REMOVE="/usr/bin/rm"                   #  pathname to rm      command
AWK="/usr/bin/awk"                     #  pathname to awk     command
PROG="$(basename $0)"                  #
#-----------------------------------------------------------------#
#  Cleanup procedure                                              #
#-----------------------------------------------------------------#
cleanup()
{
 TST=$(${REMOVE} "${INF1}" "${INF2}" 1>/dev/null 2>/dev/null)
 exit -09
}
#-----------------------------------------------------------------#
#  Usage information                                              #
#-----------------------------------------------------------------#
usage()
{
 echo "\nUsage:  $PROG  backup_file_full_name"
 echo "\n\tDefault recovery of NCS and License Use Management related definitions"
 echo "\tand database files\n"
 cleanup
}
#-----------------------------------------------------------------#
#  Test for valid input or display usage() information            #
#-----------------------------------------------------------------#
if [[ $# = 0 ]]
then
  usage
fi

if [ "${1}" = '-h' -o "${1}" = '?' ]; then
   usage
fi
#-----------------------------------------------------------------#
#  Prepare the variables                                          #
#-----------------------------------------------------------------#
integer VAL1 VAL2
SERVER="$(hostname)"
TODAY=$(date +%m_%d_%y)
RESTOREF="${1:-"/home/backup/mybackup"}"   #  database back-up media
INF1="/tmp/.irecov.$$"                     #  temp. scratch file
INF2="/tmp/.inventory.$$"                  #  temp. scratch file
I4LS="/etc/i4ls.rc"                        #  lum startup file
#-----------------------------------------------------------------#
#                                                                 #
#  This is the shell script's master loop. It performs the        #
#  following steps:                                               #
#                                                                 #
#  1.) Stops all running NCS and License Use Management daemons   #
#  2.) Writes a list of the current definition and database files #
#      into a temporary file                                      #
#  3.) Writes a list of the files saved in the backup media into  #
#      a temporary file                                           #
#  4.) Compares both temporary files. If the contents are not     #
#      the same, a list of the missing files is displayed, and the#
#      user is asked whether to continue                          #
#  5.) If the user wants to continue, the definition and database #
#      files are removed from the system,and the backup files are #
#      restored                                                   #
#                                                                 #
#-----------------------------------------------------------------#
#                                                                 #
#  1.) Stop all running NCS and License Use Management deamons    #
#                                                                 #
#-----------------------------------------------------------------#
/opt/lum/ls/os/hpux/bin/i4cfg -stop
sleep 5  # wait for the i4lmd to stop
#-----------------------------------------------------------------#
#  2.) Write a list of the current definition and database files  #
#      into a temporary file                                      #
#  ===> NOTE:                                                     #
#  The default configuration names are shown: please change them  #
#  according to your environment.                                 #
#  logdbNN, llmlgNN and crlogNN files can be also customized      #
#  in number: insert additional lines as needed.                  #
#-----------------------------------------------------------------#
echo "\t*********************************************************************"
echo "\tfollowing definition and database files have been found"
for FILENAME in  /etc/lum/ncs/glb_site.txt  \
                 /etc/lum/ncs/glb_obj.txt   \
                 /etc/lum/ncs/glb.e         \
                 /etc/lum/ncs/glb.p         \
                 /etc/lum/ncs/glb_log       \
                 /var/lum/licdb.dat    \
                 /var/lum/licdb.idx    \
                 /var/lum/crpdb.dat    \
                 /var/lum/crpdb.idx    \
                 /var/lum/llmdb.dat    \
                 /var/lum/llmdb.idx    \
                 /var/lum/usrdb.dat    \
                 /var/lum/usrdb.idx    \
                 /var/lum/adddb.dat    \
                 /var/lum/adddb.idx    \
                 /var/lum/nodelock     \
                 /var/lum/i4ls.ini     \
                 /var/lum/user_file    \
                 /var/lum/logdb00_.dat \
                 /var/lum/logdb01.dat  \
                 /var/lum/logdb00_.idx \
                 /var/lum/logdb01.idx  \
                 /var/lum/crlog00_.dat \
                 /var/lum/crlog01.dat  \
                 /var/lum/crlog00_.idx \
                 /var/lum/crlog01.idx  \
                 /var/lum/llmlg00_.dat \
                 /var/lum/llmlg01.dat  \
                 /var/lum/llmlg00_.idx \
                 /var/lum/llmlg01.idx

 do
 if [ -f ${FILENAME} ]
   then
   echo "$FILENAME" >> ${INF2}
 fi
done
echo "\t...... o.k. ........................................................."
echo "\t*********************************************************************"
#-----------------------------------------------------------------#
#  3.) Write a list of the files saved in the backup media into   #
#      a temporary file                                           #
#-----------------------------------------------------------------#
#RET=$(${RESTORE} -Tqf "${RESTOREF}" 1>${INF1})
RET=$(${RESTORE} $1 > ${INF1})
#-----------------------------------------------------------------#
#  4.) Compare both temporary files. If the contents are not      #
#      the same, display a list of the missing files, and ask the #
#      user whether to continue                                   #
#-----------------------------------------------------------------#
echo "\tcomparing current system files with files available on backup media"
VAL1=$(wc -l ${INF1} | ${AWK} ' { print $1}')
VAL2=$(wc -l ${INF2} | ${AWK} ' { print $1}')
#
if [ ${VAL1} -ne ${VAL2} ]
then
        if [ ${VAL1} -lt ${VAL2} ]
  then
      cat $INF2 | \
      while read INVENSTRING
      do
            RET1=$(grep ${INVENSTRING} ${INF1})
            if [ "${RET1}" = "" ]
                then
              INMISS="${INVENSTRING}\n\t${INMISS}"
            fi
      done
      if [ "${INMISS}" != "" ]
        then
    echo "\n\tfollowing files are missing on your backup media"
    echo "\n\t$INMISS"
    echo "\tcontinuing may lead to unpredictable results"
    echo "\tpls check what has been changed on the system configuration\n"
      fi
        else
    cat $INF1 | \
    while read RESTORESTRING
    do
        RET2=$(grep ${RESTORESTRING} ${INF2})
        if [ "${RET2}" = "" ]
            then
                  RESMISS="${RESTORESTRING}\n\t${RESMISS}"
        fi
    done
    if [ "${RESMISS}" != "" ]
      then
   echo "\n\tfollowing files are missing on your current system"
   echo "\n\t$RESMISS"
   echo "\tcontinuing may lead to unpredictable results"
   echo "\tpls check what has been changed on the system configuration\n"
    fi
        fi
        echo "\nDo you still want to continue? y/n: "
        read ANS
        if [ "$ANS" != "y" ]
        then
          cleanup
        fi
fi
echo "\t...... o.k. ........................................................."
echo "\t*********************************************************************"
#-----------------------------------------------------------------#
#  5.) Remove database and definition files                       #
#-----------------------------------------------------------------#
cat $INF2 | \
 while read FILENAME
 do
  echo "\tremoving $FILENAME"
  RET=$(${REMOVE} ${FILENAME} 1>/dev/null 2>/dev/null)
 done
${REMOVE} /tmp/llbdb.dat
echo "\t...... o.k. ........................................................."
echo "\t*********************************************************************"
#-----------------------------------------------------------------#
#     Restore from backup media.                                  #
#-----------------------------------------------------------------#
echo "\tstarting the restore process"
RET=$(${RESTORE} $1)
echo "\t...... o.k. ........................................................."
echo "\t*********************************************************************"
#-----------------------------------------------------------------#
# EOF                                                             #
#-----------------------------------------------------------------#
cleanup
